@@ -8,7 +8,7 @@ sudo.utils
 from django.core.signing import BadSignature
 from django.utils.crypto import get_random_string
 
-from sudo.settings import COOKIE_NAME, COOKIE_AGE
+from sudo.settings import COOKIE_NAME, COOKIE_AGE, COOKIE_SALT
 
 
 def grant_sudo_privileges(request, max_age=COOKIE_AGE):
@@ -52,7 +52,7 @@ def has_sudo_privileges(request):
         try:
             request._sudo = (
                 request.user.is_authenticated() and
-                request.get_signed_cookie(COOKIE_NAME, max_age=COOKIE_AGE) ==
+                request.get_signed_cookie(COOKIE_NAME, salt=COOKIE_SALT, max_age=COOKIE_AGE) ==
                 request.session[COOKIE_NAME]
             )
         except (KeyError, BadSignature):
